pub struct Color {
pub r: U7,
pub g: U7,
pub b: U7,
}Expand description
Represents an RGB color with component values limited to the range [0, 127]. Used for setting custom colors on the Launchkey device.
Fields
r: U7g: U7b: U7Implementations
Sourceimpl Color
impl Color
Sourcepub fn try_new(r: u8, g: u8, b: u8) -> Result<Self, String>
pub fn try_new(r: u8, g: u8, b: u8) -> Result<Self, String>
Tries to create a new Color if all RGB values are within the valid range [0, 127].
Sourcepub fn from_full_range(r: u8, g: u8, b: u8) -> Self
pub fn from_full_range(r: u8, g: u8, b: u8) -> Self
Creates a new Color by converting RGB values from the full range [0, 255] to [0, 127].
Automatically scales down the values.