LaunchKeyButton

Enum LaunchKeyButton 

pub enum LaunchKeyButton {
Show 17 variants Shift, PreviousTrack, NextTrack, EncoderMoveUp, EncoderMoveDown, PadBankUp, PadBankDown, SceneLaunch, Function, CaptureMIDI, UndoRedo, Quantise, Metronome, Stop, Loop, Play, Record,
}
Enumeration of all supported Launchkey buttons that can be programmatically controlled.

Variants



Shift



PreviousTrack



NextTrack



EncoderMoveUp



EncoderMoveDown



PadBankUp



PadBankDown



SceneLaunch



Function



CaptureMIDI



UndoRedo



Quantise



Metronome



Stop



Loop



Play



Record

Implementations

Source

impl LaunchKeyButton

pub fn to_value(&self) -> u8

Returns the associated value for the enum variant.

pub fn from_value(value: u8) -> Option<LaunchKeyButton>

Returns the enum variant corresponding to the value, or None if invalid.