Encoder

Enum Encoder 

pub enum Encoder {
    Encoder1,
    Encoder2,
    Encoder3,
    Encoder4,
    Encoder5,
    Encoder6,
    Encoder7,
    Encoder8,
}

Variants



Encoder1



Encoder2



Encoder3



Encoder4



Encoder5



Encoder6



Encoder7



Encoder8

Implementations

Source

impl Encoder

pub fn to_value_mode(&self, mode: EncoderCCIndex) -> u8

Converts the enum variant to its associated value based on the given mode.

pub fn from_value_mode(value: u8, mode: EncoderCCIndex) -> Option<Encoder>

Converts a value back to its corresponding enum variant based on the mode.

pub fn from_value(value: u8) -> Option<(Encoder, EncoderCCIndex)>

Returns the enum variant and its associated mode from a given value.

Source

impl Encoder

pub fn to_index(self, is_absolute: bool) -> u8

Get the correct Control Change index based on whether the encoder is in absolute or relative mode

pub fn all() -> impl Iterator<Item = Self>

Get all possible variants of Encoder.

pub fn count() -> usize

Get the count of all variants

pub fn from_index(index: usize) -> Option<Self>

Safely get a variant by its index