pub enum Encoder {
Encoder1,
Encoder2,
Encoder3,
Encoder4,
Encoder5,
Encoder6,
Encoder7,
Encoder8,
}Variants
Implementations
Sourceimpl Encoder
impl Encoder
Sourcepub fn to_value_mode(&self, mode: EncoderCCIndex) -> u8
pub fn to_value_mode(&self, mode: EncoderCCIndex) -> u8
Converts the enum variant to its associated value based on the given mode.
Sourcepub fn from_value_mode(value: u8, mode: EncoderCCIndex) -> Option<Encoder>
pub fn from_value_mode(value: u8, mode: EncoderCCIndex) -> Option<Encoder>
Converts a value back to its corresponding enum variant based on the mode.
Sourcepub fn from_value(value: u8) -> Option<(Encoder, EncoderCCIndex)>
pub fn from_value(value: u8) -> Option<(Encoder, EncoderCCIndex)>
Returns the enum variant and its associated mode from a given value.